@@ -1,33 +1,34 @@
+use crate::dbuffer::DBuffer;
 use crate::http::{body::*, header::*, request::*, response::*, StatusCode};
+use crate::http::Header;
 use crate::log;
-use crate::ressource::RessourceLoader;
+use crate::resource::ResourceLoader;
 use crate::route::*;
 use crate::ThreadPool;
-use std::io::{Read, Write};
+use std::io::Write;
 use std::net::IpAddr;
 use std::net::TcpListener;
 
-/// a rsweb server using a ressource loader and router
+/// a rsweb server using a resource loader and router
 pub struct Server {
     tp: ThreadPool,
-    rl: RessourceLoader,
+    rl: ResourceLoader,
     port: usize,
     ip: IpAddr,
     router: Router,
 }
 
 impl Server {
-
     /// create a new server
     /// # Arguments
     /// * `capacity`: the amount of threads to use
-    /// * `rl`: the ressource loader to use
+    /// * `rl`: the resource loader to use
     /// * `router`: the router to use
     /// * `port`: the port to use
     /// * `ip`: the ip address to run on
     pub fn new(
         capacity: usize,
-        rl: RessourceLoader,
+        rl: ResourceLoader,
         router: Router,
         port: usize,
         ip: IpAddr,
@@ -62,42 +63,55 @@ impl Server {
 
         let mut logger = log::Logger::new();
         logger.set_term(btui::Terminal::default());
-        logger.log("starting server", log::LogType::Log);
-        match logger.set_logfile(lf) {
-            Ok(_) => (),
-            Err(_) => {
-                logger.log("couldn't set logfile", log::LogType::Error);
-            }
+        if let Err(e) =  logger.set_logfile(lf) {
+            logger.log("couldn't open logfile", log::LogType::Error);
         }
+        logger.log("starting server", log::LogType::Log);
         for stream in listener.incoming() {
             match stream {
                 Ok(mut stream) => {
                     let mut resload = self.rl.clone();
                     let router = self.router.clone();
+                    let logfile = lf.to_string();
                     //let mut lg = logger.clone();
                     self.tp.execute(move || {
                         let mut logging = log::Logger::new();
                         logging.set_term(btui::Terminal::new());
-                        let mut buf = [0u8; 1024];
-                        match stream.read(&mut buf) {
-                            Ok(_) => (),
-                            Err(_) => (),
+                        let _ = logging.set_logfile(logfile.as_str());
+                        let mut buf = DBuffer::new();
+                        if let Err(_) = buf.read_http_request(&mut stream) {
+                            logging.log("failed to read from stream", log::LogType::Error);
+                        }
+                        let data: String = match buf.to_string() {
+                            Ok(n) => n,
+                            Err(_) => {
+                                logging.log("failed to parse data to utf8", log::LogType::Error);
+                                String::new()
+                            }
                         };
-                        let data: String = String::from(std::str::from_utf8(&buf).unwrap());
                         if let Ok(req) = HTTPRequest::from_string(data) {
-                            logging.log(format!("request: {} {}", req.get_method(), req.get_path()), log::LogType::Log);
+                            logging.log(
+                                format!("request: {} {}", req.get_method(), req.get_path()),
+                                log::LogType::Log,
+                            );
                             if let Some(n) = router.lookup(req.get_path()) {
                                 let resp = match n {
                                     Route::Route(p) => p,
                                     Route::Alias(q) => {
-                                        let response_body = resload.load(q[1..].to_string());
+                                        let (response_body, mime_type) =
+                                            resload.load(q[1..].to_string());
+                                        let mut header = Header::new(StatusCode::Ok);
+                                        header.add_kv_pair(
+                                            String::from("Content-Type"),
+                                            mime_type.to_string(),
+                                        );
                                         let mut response = HTTPResponse::new(
-                                            Header::new(StatusCode::Ok, Vec::new()),
+                                            header,
                                             Body::new(response_body.clone()),
                                         );
                                         if response_body.is_empty() {
                                             response = HTTPResponse::new(
-                                                Header::new(StatusCode::NotFound, Vec::new()),
+                                                Header::new(StatusCode::NotFound),
                                                 Body::new(String::from("<h1>404 not found</h1>")),
                                             );
                                         }
@@ -106,33 +120,50 @@ impl Server {
                                 };
                                 match stream.write(resp.to_string().as_str().as_bytes()) {
                                     Ok(_) => (),
-                                    Err(_) => logging.log("failed to write to stream", log::LogType::Error),
+                                    Err(_) => logging
+                                        .log("failed to write to stream", log::LogType::Error),
                                 }
                                 match stream.flush() {
                                     Ok(_) => (),
-                                    Err(_) => logging.log("failed to flush stream", log::LogType::Error),
+                                    Err(_) => {
+                                        logging.log("failed to flush stream", log::LogType::Error)
+                                    }
                                 }
                             } else {
-                                let response_body = resload.load(req.get_path()[1..].to_string());
-                                let mut response = HTTPResponse::new(
-                                    Header::new(StatusCode::Ok, Vec::new()),
-                                    Body::new(response_body.clone()),
+                                let (response_body, mime_type) =
+                                    resload.load(req.get_path()[1..].to_string());
+                                let mut header = Header::new(StatusCode::Ok);
+                                header.add_kv_pair(
+                                    String::from("Content-Type"),
+                                    mime_type.to_string(),
                                 );
+                                let mut response =
+                                    HTTPResponse::new(header, Body::new(response_body.clone()));
                                 if response_body.is_empty() {
+                                    let mut header = Header::new(StatusCode::NotFound);
+                                    header.add_kv_pair(
+                                        String::from("Content-Type"),
+                                        String::from("text/html"),
+                                    );
                                     response = HTTPResponse::new(
-                                        Header::new(StatusCode::NotFound, Vec::new()),
+                                        header,
                                         Body::new(String::from("<h1>404 not found</h1>")),
                                     );
                                 }
                                 match stream.write(response.to_string().as_str().as_bytes()) {
                                     Ok(_) => (),
-                                    Err(_) => logging.log("failed to write to stream", log::LogType::Error),
+                                    Err(_) => logging
+                                        .log("failed to write to stream", log::LogType::Error),
                                 }
                                 match stream.flush() {
                                     Ok(_) => (),
-                                    Err(_) => logging.log("failed to flush stream", log::LogType::Error),
+                                    Err(_) => {
+                                        logging.log("failed to flush stream", log::LogType::Error)
+                                    }
                                 }
                             }
+                        } else {
+                            logging.log("failed to parse request", log::LogType::Error);
                         }
                         match stream.shutdown(std::net::Shutdown::Both) {
                             Ok(_) => (),
